"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FluentdService = void 0;
const logger_1 = require("@fluent-org/logger");
const common_1 = require("@nestjs/common");
class FluentdService {
    constructor({ host, port = 24224, namePrefix, reconnectDelayMs = 10000, ackTimeoutMs = 5000, sendMessageRetryDelayMs = 10000, sendMessageRetryAttempts = 10, maxQueueLength = 1000, }) {
        this.fluentClient = new logger_1.FluentClient(namePrefix, {
            socket: {
                host,
                port,
                reconnect: {
                    backoff: 1,
                    delay: reconnectDelayMs,
                    maxDelay: reconnectDelayMs,
                    minDelay: reconnectDelayMs,
                },
            },
            ack: {
                ackTimeout: ackTimeoutMs,
            },
            eventMode: 'Message',
            eventRetry: {
                maxDelay: sendMessageRetryDelayMs,
                delay: sendMessageRetryDelayMs,
                minDelay: sendMessageRetryDelayMs,
                attempts: sendMessageRetryAttempts,
                backoff: 1,
            },
            sendQueueMaxLimit: {
                length: maxQueueLength,
            },
        });
        this.fluentClient.socketOn(logger_1.FluentSocketEvent.ERROR, (err) => {
            common_1.Logger.error(err);
        });
    }
    async emit(tag, data) {
        return this.fluentClient.emit(tag, data);
    }
}
exports.FluentdService = FluentdService;
//# sourceMappingURL=fluentd.service.js.map